## 0.14.2.5 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 0.14.2.4 (2023-03-27)

Add defaults for third-party stubs A-D (#9952)

## 0.14.2.3 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.14.2.2 (2023-02-09)

Use `_typeshed.FileDescriptorOrPath` in stubs (#9695)

## 0.14.2.1 (2023-02-07)

Bump mypy to 1.0 (#9684)

## 0.14.2 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 0.14.1 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 0.14.0 (2022-02-05)

Add stubs for `chevron` package (#7139)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

